@@ -9,7 +9,7 @@ test_that("fone_dataset basic checks", {
 
   res <- fone_dataset(dataset_id = "DS00047", resource_id = "RS00005", limit = 10L)
   expect_s3_class(res, "data.frame")
-  expect_identical(dim(res), c(10L, 33L))
+  expect_shape(res, dim = c(10L, 33L))
 })
 
 test_that("fone_view basic checks", {
@@ -23,5 +23,5 @@ test_that("fone_view basic checks", {
 
   res <- fone_view(view_id = "DS01538", limit = 10L)
   expect_s3_class(res, "data.frame")
-  expect_identical(dim(res), c(10L, 6L))
+  expect_shape(res, dim = c(10L, 6L))
 })
